@@ -4,7 +4,7 @@
 
 """
 
-__all__ = ['UndefinedConditionError', 'InvalidConditionError',]
+__all__ = ["UndefinedConditionError", "InvalidConditionError"]
 
 
 class UndefinedConditionError(NotImplementedError):
